==> aria2-1.7.2.tar.xz: aria2-1.7.2/src/DownloadCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DOWNLOAD_COMMAND_H_
#define _D_DOWNLOAD_COMMAND_H_

#include "AbstractCommand.h"

namespace aria2 {

class Decoder;
class PeerStat;
#ifdef ENABLE_MESSAGE_DIGEST
class MessageDigestContext;
#endif // ENABLE_MESSAGE_DIGEST

class DownloadCommand : public AbstractCommand {
private:
  unsigned char* _buf;

  time_t startupIdleTime;
  unsigned int lowestDownloadSpeedLimit;
  SharedHandle<PeerStat> peerStat;

#ifdef ENABLE_MESSAGE_DIGEST

  bool _pieceHashValidationEnabled;

  SharedHandle<MessageDigestContext> _messageDigestContext;

#endif // ENABLE_MESSAGE_DIGEST

  void validatePieceHash(const SharedHandle<Segment>& segment,
			 const std::string& expectedPieceHash,
			 const std::string& actualPieceHash);

  void checkLowestDownloadSpeed() const;
protected:
  SharedHandle<Decoder> _transferEncodingDecoder;

  SharedHandle<Decoder> _contentEncodingDecoder;

  virtual bool executeInternal();

  virtual bool prepareForNextSegment();

public:
  DownloadCommand(int cuid,
		  const SharedHandle<Request>& req,
		  const SharedHandle<FileEntry>& fileEntry,
		  RequestGroup* requestGroup,
		  DownloadEngine* e,
		  const SharedHandle<SocketCore>& s);
  virtual ~DownloadCommand();

  void setTransferEncodingDecoder(const SharedHandle<Decoder>& decoder);

  void setContentEncodingDecoder(const SharedHandle<Decoder>& decoder);

  void setStartupIdleTime(time_t startupIdleTime) {
    this->startupIdleTime = startupIdleTime;
  }

  void setLowestDownloadSpeedLimit(unsigned int lowestDownloadSpeedLimit) {
    this->lowestDownloadSpeedLimit = lowestDownloadSpeedLimit;
  }
};

} // namespace aria2

#endif // _D_DOWNLOAD_COMMAND_H_

==> aria2-1.9.5.tar.xz: aria2-1.9.5/src/DownloadCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DOWNLOAD_COMMAND_H_
#define _D_DOWNLOAD_COMMAND_H_

#include "AbstractCommand.h"

namespace aria2 {

class Decoder;
class PeerStat;
#ifdef ENABLE_MESSAGE_DIGEST
class MessageDigestContext;
#endif // ENABLE_MESSAGE_DIGEST

class DownloadCommand : public AbstractCommand {
private:
  unsigned char* buf_;

  time_t startupIdleTime_;
  unsigned int lowestDownloadSpeedLimit_;
  SharedHandle<PeerStat> peerStat_;

#ifdef ENABLE_MESSAGE_DIGEST

  bool pieceHashValidationEnabled_;

  SharedHandle<MessageDigestContext> messageDigestContext_;

#endif // ENABLE_MESSAGE_DIGEST

  void validatePieceHash(const SharedHandle<Segment>& segment,
                         const std::string& expectedPieceHash,
                         const std::string& actualPieceHash);

  void checkLowestDownloadSpeed() const;

  SharedHandle<Decoder> transferEncodingDecoder_;

  SharedHandle<Decoder> contentEncodingDecoder_;
protected:
  virtual bool executeInternal();

  virtual bool prepareForNextSegment();
public:
  DownloadCommand(cuid_t cuid,
                  const SharedHandle<Request>& req,
                  const SharedHandle<FileEntry>& fileEntry,
                  RequestGroup* requestGroup,
                  DownloadEngine* e,
                  const SharedHandle<SocketCore>& s);
  virtual ~DownloadCommand();

  const SharedHandle<Decoder>& getTransferEncodingDecoder() const
  {
    return transferEncodingDecoder_;
  }

  void setTransferEncodingDecoder(const SharedHandle<Decoder>& decoder);

  const SharedHandle<Decoder>& getContentEncodingDecoder() const
  {
    return contentEncodingDecoder_;
  }

  void setContentEncodingDecoder(const SharedHandle<Decoder>& decoder);

  void setStartupIdleTime(time_t startupIdleTime)
  {
    startupIdleTime_ = startupIdleTime;
  }

  void setLowestDownloadSpeedLimit(unsigned int lowestDownloadSpeedLimit)
  {
    lowestDownloadSpeedLimit_ = lowestDownloadSpeedLimit;
  }
};

} // namespace aria2

#endif // _D_DOWNLOAD_COMMAND_H_
